#  @@@@@@  @@@@@@ @@@@@@@ @@@@@@@  @@@@@@
# @@!  @@@@@!  @@@@@!  @@@@@!  @@@@@!  @@@
# @!@  !@!@!@  !@!@!@!@!@ @!@!!@! @!@!@!@!
# !!:!!:!:!!:  !!!!!:  !!!!!: :!! !!:  !!!
#  : :. :::: :. : :: : ::  :   : : :   : :
#
# This is the configuration file for qobra.
# qobra will look for a configuration file in ~/.config/qobra
# and load the default configuration if it is not found.

# Music directory
# Set this to avoid having to type the path in the command
# line
music_dir = ''

# Colors
# Options are:
# black, red, green, yellow, blue, magenta, cyan and white

# Window colors (the border color is determined by window_fg)
window_fg = 'red'
window_bg = 'black'

# Songs colors
songs_fg = 'red'
songs_bg = 'black'

# Selected song colors
current_song_fg = 'black'
current_song_bg = 'red'

##############
# Statusline #
##############

# Current status indicator
# Playing  colors
playing_fg = 'green'
playing_bg = 'black'
# Paused colors
paused_fg = 'red'
paused_bg = 'black'

# Current song colors
statusbar_song_fg = 'white'
statusbar_song_bg = 'black'

# Mode indicator
# Normal mode colors
normal_mode_fg = 'cyan'
normal_mode_bg = 'black'
# Suffle mode colors
shuffle_mode_fg = 'yellow'
shuffle_mode_bg = 'black'

# Search bar

# Search placeholder colors
search_fg = 'magenta'
search_bg = 'black'

# Search box colors
search_box_fg = 'red'
search_box_bg = 'black'

# MISC
# Draw a border around the window?
border = True

# Background fill character
# This can't be an empty string
bg_char = ' '
